==> neo4j-kernel-4.4.3-sources.jar: org/neo4j/kernel/impl/index/schema/ListBasedBlockEntryCursor.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.index.schema;

import java.util.Iterator;

class ListBasedBlockEntryCursor<KEY,VALUE> implements BlockEntryCursor<KEY,VALUE>
{
    private final Iterator<BlockEntry<KEY,VALUE>> entries;
    private BlockEntry<KEY,VALUE> next;

    ListBasedBlockEntryCursor( Iterable<BlockEntry<KEY,VALUE>> entries )
    {
        this.entries = entries.iterator();
    }

    @Override
    public boolean next()
    {
        if ( entries.hasNext() )
        {
            next = entries.next();
            return true;
        }
        return false;
    }

    @Override
    public KEY key()
    {
        return next.key();
    }

    @Override
    public VALUE value()
    {
        return next.value();
    }

    @Override
    public void close()
    {   // no-op
    }
}

==> neo4j-kernel-5.3.0-sources.jar: org/neo4j/kernel/impl/index/schema/ListBasedBlockEntryCursor.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.index.schema;

import java.util.Iterator;

class ListBasedBlockEntryCursor<KEY, VALUE> implements BlockEntryCursor<KEY, VALUE> {
    private final Iterator<BlockEntry<KEY, VALUE>> entries;
    private BlockEntry<KEY, VALUE> next;

    ListBasedBlockEntryCursor(Iterable<BlockEntry<KEY, VALUE>> entries) {
        this.entries = entries.iterator();
    }

    @Override
    public boolean next() {
        if (entries.hasNext()) {
            next = entries.next();
            return true;
        }
        return false;
    }

    @Override
    public KEY key() {
        return next.key();
    }

    @Override
    public VALUE value() {
        return next.value();
    }

    @Override
    public void close() { // no-op
    }
}
